@@ -58,7 +58,7 @@
 #include <wtf/Vector.h>
 #include <assembler/MacroAssembler.h>
 
-#ifdef V4_ENABLE_JIT
+#if QT_CONFIG(qml_jit)
 
 QT_BEGIN_NAMESPACE
 
@@ -449,7 +449,7 @@ public:
     // r6 is used by MacroAssemblerARMv7
     static const RegisterID JSStackFrameRegister     = JSC::ARMRegisters::r8;
     static const RegisterID CppStackFrameRegister    = JSC::ARMRegisters::r10;
-#if CPU(ARM_THUMB2) || defined(V4_BOOTSTRAP)
+#if CPU(ARM_THUMB2)
     static const RegisterID FramePointerRegister     = JSC::ARMRegisters::r7;
     static const RegisterID EngineRegister           = JSC::ARMRegisters::r11;
 #else // Thumbs down
@@ -587,7 +587,7 @@ public:
     Address loadCompilationUnitPtr(RegisterID target)
     {
         Address addr = loadFunctionPtr(target);
-        addr.offset = offsetof(QV4::Function, compilationUnit);
+        addr.offset = offsetof(QV4::FunctionData, compilationUnit);
         loadPtr(addr, target);
         return Address(target);
     }
@@ -619,6 +619,9 @@ public:
         for (Jump j : catchyJumps)
             j.link(this);
 
+        // We don't need to check for isInterrupted here because if that is set,
+        // then the first checkException() in any exception handler will find another "exception"
+        // and jump out of the exception handler.
         loadPtr(exceptionHandlerAddress(), ScratchRegister);
         Jump exitFunction = branchPtr(Equal, ScratchRegister, TrustedImmPtr(0));
         loadUndefined();
@@ -633,6 +636,8 @@ public:
 
     void checkException()
     {
+        // This actually reads 4 bytes, starting at hasException.
+        // Therefore, it also reads the isInterrupted flag, and triggers an exception on that.
         addCatchyJump(
                     branch32(NotEqual,
                              Address(EngineRegister, offsetof(EngineBase, hasException)),
@@ -670,7 +675,8 @@ public:
 
     void addLabelForOffset(int offset)
     {
-        labelForOffset.insert(offset, label());
+        if (!labelForOffset.contains(offset))
+            labelForOffset.insert(offset, label());
     }
 
     void addJumpToOffset(const Jump &jump, int offset)
@@ -699,9 +705,10 @@ public:
     void passAddressAsArg(Address addr, int arg);
     void passCppFrameAsArg(int arg);
     void passInt32AsArg(int value, int arg);
-    void callRuntime(const char *functionName, const void *funcPtr);
-    void callRuntimeUnchecked(const char *functionName, const void *funcPtr);
-    void tailCallRuntime(const char *functionName, const void *funcPtr);
+    void passPointerAsArg(void *ptr, int arg);
+    void callRuntime(const void *funcPtr, const char *functionName = nullptr);
+    void callRuntimeUnchecked(const void *funcPtr, const char *functionName = nullptr);
+    void tailCallRuntime(const void *funcPtr, const char *functionName = nullptr);
     void setTailCallArg(RegisterID src, int arg);
     Address jsAlloca(int slotCount);
     void storeInt32AsValue(int srcInt, Address destAddr);
@@ -733,6 +740,6 @@ private:
 
 QT_END_NAMESPACE
 
-#endif // V4_ENABLE_JIT
+#endif // QT_CONFIG(qml_jit)
 
 #endif // QV4PLATFORMASSEMBLER_P_H
