@@ -3,23 +3,27 @@
 
 /*---
 esid: sec-array.prototype.reduce
-es5id: 15.4.4.21-8-b-iii-1-8
+es5id: 15.4.4.21-8-b-iii-1-18
 description: >
-    Array.prototype.reduce - element to be retrieved is inherited data
-    property on an Array
+    Array.prototype.reduce - element to be retrieved is own accessor
+    property without a get function on an Array
 ---*/
 
 var testResult = false;
 
 function callbackfn(prevVal, curVal, idx, obj) {
   if (idx === 1) {
-    testResult = (prevVal === 0);
+    testResult = (prevVal === undefined);
   }
 }
 
-Array.prototype[0] = 0;
-Array.prototype[1] = 1;
-Array.prototype[2] = 2;
-[, , , ].reduce(callbackfn);
+var arr = [, 1, 2];
+
+Object.defineProperty(arr, "0", {
+  set: function() {},
+  configurable: true
+});
+
+arr.reduce(callbackfn);
 
 assert(testResult, 'testResult !== true');
