@@ -3,8 +3,8 @@
 
 /*---
 esid: sec-array.prototype.some
-es5id: 15.4.4.17-3-10
-description: Array.prototype.some - value of 'length' is a number (value is NaN)
+es5id: 15.4.4.17-3-4
+description: Array.prototype.some - value of 'length' is a number (value is +0)
 ---*/
 
 var accessed = false;
@@ -16,7 +16,7 @@ function callbackfn(val, idx, obj) {
 
 var obj = {
   0: 11,
-  length: NaN
+  length: +0
 };
 
 assert.sameValue(Array.prototype.some.call(obj, callbackfn), false, 'Array.prototype.some.call(obj, callbackfn)');
