@@ -2,21 +2,22 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.3.5.4_2-72gs
+es5id: 15.3.5.4_2-37gs
 description: >
     Strict mode - checking access to strict function caller from
-    non-strict function (strict function declaration called by
-    Function.prototype.bind(undefined)())
+    non-strict function (FunctionExpression defined within an
+    Anonymous FunctionExpression with a strict directive prologue)
 flags: [noStrict]
 ---*/
 
-function f() {
-  "use strict";
-  gNonStrict();
-};
-
 assert.throws(TypeError, function() {
-  f.bind(undefined)();
+  (function() {
+    "use strict";
+    var f = function() {
+      gNonStrict();
+    }
+    f();
+  })();
 });
 
 function gNonStrict() {
