@@ -2,12 +2,12 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.2-2-27
+es5id: 15.2.3.2-2-24
 description: >
     Object.getPrototypeOf returns the [[Prototype]] of its parameter
-    (Error object)
+    (Number object)
 ---*/
 
-var obj = new Error();
+var obj = new Number(-3);
 
-assert.sameValue(Object.getPrototypeOf(obj), Error.prototype, 'Object.getPrototypeOf(obj)');
+assert.sameValue(Object.getPrototypeOf(obj), Number.prototype, 'Object.getPrototypeOf(obj)');
