@@ -2,11 +2,10 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.13-2-2
-description: Object.isExtensible returns true for all built-in objects (Object)
+es5id: 15.2.3.13-2-8
+description: Object.isExtensible returns true for all built-in objects (Math)
 ---*/
 
-var o = {};
-var e = Object.isExtensible(o);
+var e = Object.isExtensible(Math);
 
 assert.sameValue(e, true, 'e');
