@@ -2,14 +2,14 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.10-3-2
+es5id: 15.2.3.10-3-3
 description: >
     Object.preventExtensions - indexed properties cannot be added into
-    the returned object
+    a Function object
 includes: [propertyHelper.js]
 ---*/
 
-var obj = {};
+var obj = function() {};
 
 assert(Object.isExtensible(obj));
 Object.preventExtensions(obj);
