@@ -2,17 +2,17 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 8.12.1-1_9
+es5id: 8.12.1-1_26
 description: >
-    Properties - [[HasOwnProperty]] (writable, non-configurable,
-    enumerable own value property)
+    Properties - [[HasOwnProperty]] (non-configurable, non-enumerable
+    own getter property)
 ---*/
 
 var o = {};
 Object.defineProperty(o, "foo", {
-  value: 42,
-  writable: true,
-  enumerable: true
+  get: function() {
+    return 42;
+  }
 });
 
 assert(o.hasOwnProperty("foo"), 'o.hasOwnProperty("foo") !== true');
