@@ -2,10 +2,10 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.5.4.20-4-51
+es5id: 15.5.4.20-4-37
 description: >
     String.prototype.trim handles whitepace and lineterminators
-    (\u000Aabc\u000A)
+    (ab\u000Cc)
 ---*/
 
-assert.sameValue("\u000Aabc\u000A".trim(), "abc", '"\u000Aabc\u000A".trim()');
+assert.sameValue("ab\u000Cc".trim(), "ab\u000Cc", '"ab\u000Cc".trim()');
