@@ -10,19 +10,17 @@ info: |
     local functions must shadow outer functions
     local function expresssions must shadow outer function expressions
     eval should use the appended object to the scope chain
-es5id: 12.14-6
+es5id: 12.14-3
 description: >
-    catch introduces scope - block-local function expression must
-    shadow outer function expression
+    catch doesn't change declaration scope - var declaration are
+    visible outside when name different from catch parameter
 ---*/
 
-  var o = {foo : function () { return 42;}};
-
   try {
-    throw o;
+    throw new Error();
   }
   catch (e) {
-    var foo = function () {};
+    var foo = "declaration in catch";
   }
 
-assert.sameValue(foo(), undefined);
+assert.sameValue(foo, "declaration in catch");
