@@ -29,7 +29,7 @@
 #include <QtQuick/private/qquickitem_p.h>
 #include <QtQuick/private/qquicktext_p.h>
 #include <QtQml/private/qqmlengine_p.h>
-#include <QtQml/private/qqmllistmodel_p.h>
+#include <QtQmlModels/private/qqmllistmodel_p.h>
 #include <QtQml/private/qqmlexpression_p.h>
 #include <QQmlComponent>
 
@@ -104,6 +104,7 @@ private slots:
     void worker_remove_list();
     void dynamic_role_data();
     void dynamic_role();
+    void correctMoves();
 };
 
 bool tst_qqmllistmodelworkerscript::compareVariantList(const QVariantList &testList, QVariant object)
@@ -162,7 +163,7 @@ QQuickItem *tst_qqmllistmodelworkerscript::createWorkerTest(QQmlEngine *eng, QQm
     QQuickItem *item = qobject_cast<QQuickItem*>(component->create());
     QQmlEngine::setContextForObject(model, eng->rootContext());
     if (item)
-        item->setProperty("model", qVariantFromValue(model));
+        item->setProperty("model", QVariant::fromValue(model));
     return item;
 }
 
@@ -842,6 +843,22 @@ void tst_qqmllistmodelworkerscript::dynamic_role()
     qApp->processEvents();
 }
 
+void tst_qqmllistmodelworkerscript::correctMoves()
+{
+    QQmlEngine engine;
+    QQmlComponent component(&engine, testFileUrl("listmodel_async_sort/main.qml"));
+    QScopedPointer<QObject> root {component.create()};
+    QVERIFY2(root, qPrintable(component.errorString()));
+    bool ok =QMetaObject::invokeMethod(root.get(), "doSort");
+    QVERIFY(ok);
+    auto check = [&](){
+        bool success = false;
+        QMetaObject::invokeMethod(root.get(), "verify", Q_RETURN_ARG(bool, success));
+        return success;
+    };
+    QTRY_VERIFY(check());
+}
+
 QTEST_MAIN(tst_qqmllistmodelworkerscript)
 
 #include "tst_qqmllistmodelworkerscript.moc"
